# scRFE (pronounced 'surf')

scRFE (single-cell identity definition using random forest modelling and recursive feature elimination) is a python package that uses a one versus all random forest classifier with recursive feature elimination to identify the set of genes necessary and sufficient to describe the different features of your single-cell RNA sequencing data.

## Installation and Documentation
Use the package manager [pip](https://pip.pypa.io/en/stable/) to install scRFE for python.

```bash
pip install scRFE
```

Find scRFE at https://pypi.org/project/scRFE/

Find our documentation at https://scrfe.readthedocs.io/en/latest/

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[MIT](https://choosealicense.com/licenses/mit/)
